package com.uc_mobileapps.examples.vaadin.entities;


import com.weebmeister.seife.anno.SeifeBinding;
import com.weebmeister.seife.anno.SeifeClass;
import com.weebmeister.seife.anno.SeifeField;

import javax.persistence.*;
import javax.validation.constraints.Size;
import java.time.Clock;
import java.time.LocalDate;

@Entity
@SeifeClass // just add this for the form binding, no special options needed
public class Customer {

    @Id
    @GeneratedValue(strategy=GenerationType.AUTO)
    private Long id;

    /**
     * This field is exposed to the forms via @SeifeField
     */
    @SeifeField
    private String firstName;

    /**
     * The mandatory flag will create a mandatory input field whenever it is bound.
     */
    @SeifeField(mandatory = true)
    private String lastName;

    /**
     * JPA Size constraint
     */
    @Size(min = 0, max = 5)
    private String title;

    /**
     * Marks the field to create a password input.
     */
    @SeifeField(dataOptions = SeifeBinding.TYPE_PASSWORD)
    private String password;

    /**
     * The new and the old java date and time api is supported.
     */
    @SeifeField
    private LocalDate birthday = LocalDate.now(Clock.systemUTC());
    /**
     * Embedded address, this can also be a regular database reference
     */
    @SeifeField
    @Embedded
    private Address address;

    /**
     * References are resolved can be traversed in the binding,
     * see {@link com.uc_mobileapps.examples.vaadin.forms.CustomerForm#favoriteProductName}
     */
    @SeifeField
    @ManyToOne
    @JoinColumn(foreignKey=@ForeignKey(name="fkFavorite"), nullable=true)
    private Product favoriteProduct;

    /**
     * Supports all of the Java nullable types.
     */
    @SeifeField
    private boolean premium;

    @SeifeField
    private boolean active = true;

    protected Customer() {}

    public Customer(String firstName, String lastName) {
        this.firstName = firstName;
        this.lastName = lastName;
    }

    public Long getId() {
        return id;
    }

    public String getFirstName() {
        return firstName;
    }

    public void setFirstName(String firstName) {
        this.firstName = firstName;
    }

    public String getLastName() {
        return lastName;
    }

    public void setLastName(String lastName) {
        this.lastName = lastName;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public LocalDate getBirthday() {
        return birthday;
    }

    public void setBirthday(LocalDate birthday) {
        this.birthday = birthday;
    }

    public Product getFavoriteProduct() {
        return favoriteProduct;
    }

    public void setFavoriteProduct(Product favoriteProduct) {
        this.favoriteProduct = favoriteProduct;
    }

    public Address getAddress() {
        return address;
    }

    public void setAddress(Address address) {
        this.address = address;
    }

    public boolean isPremium() {
        return premium;
    }

    public void setPremium(boolean premium) {
        this.premium = premium;
    }

    public boolean isActive() {
        return active;
    }

    public void setActive(boolean active) {
        this.active = active;
    }
}