package com.uc_mobileapps.examples.vaadin.views;

import com.uc_mobileapps.examples.vaadin.dao.CustomerRepository;
import com.uc_mobileapps.examples.vaadin.dao.ProductRepository;
import com.uc_mobileapps.examples.vaadin.entities.Address;
import com.uc_mobileapps.examples.vaadin.entities.Customer;
import com.uc_mobileapps.examples.vaadin.entities.Product;
import com.uc_mobileapps.examples.vaadin.forms.CustomerForm;
import com.vaadin.flow.component.AttachEvent;
import com.vaadin.flow.component.dependency.JsModule;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;
import com.vaadin.flow.router.Route;
import com.vaadin.flow.router.RouterLink;
import com.vaadin.flow.spring.annotation.SpringComponent;
import com.vaadin.flow.spring.annotation.UIScope;
import com.vaadin.flow.theme.Theme;
import com.vaadin.flow.theme.lumo.Lumo;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * Shows how efficient and flexible a simple product editor
 * can be achieved with the seife code generation. The generated gui bindings can be found in the product form.
 * See <a href="https://uc-mobileapps.com/seife-annotation-processor/">Seife Annotation Processor</a>.
 */
@UIScope
@SpringComponent
@Route(value = SimpleEditor.PATH)
@Theme(value = Lumo.class, variant = Lumo.DARK)
@JsModule("./styles/shared-styles.html")
public class SimpleEditor extends VerticalLayout {

    public static final String PATH = "create-customer";
    private final CustomerForm customerForm;
    private final CustomerRepository customerRepository;
    private final ProductRepository productRepository;

    @Autowired
    public SimpleEditor(CustomerForm customerForm, CustomerRepository customerRepository, ProductRepository productRepository) {
        this.customerForm = customerForm;
        this.customerRepository = customerRepository;
        this.productRepository = productRepository;

        RouterLink navigateList = new RouterLink("Show List", SimpleGrid.class);

        add(new Label("Create customer"));
        add(customerForm);
        add(navigateList);

        setupSampleData();
    }

    private void setupSampleData() {
        if (productRepository.count() > 0) {
            return;
        }
        Product product = new Product();
        product.setName("Seamless Vaadin");
        productRepository.save(product);
    }

    @Override
    protected void onAttach(AttachEvent attachEvent) {
        super.onAttach(attachEvent);

        Customer customer = new Customer("Scott", "O'Brien");
        customer.setAddress(new Address());
        customer.getAddress().setStreet("Frankfurter Tor");
        customer.setFavoriteProduct(productRepository.findAll().iterator().next());

        customerForm.setCustomer(customer);
    }
}
